==> javascript-sdk-1.19.0.tgz: package/src/types.ts <==
import { DateAndPlaceOfBirth, NationalIdentification } from 'ivms/types';

export type Theme = {
  primaryColor: string;
  secondaryColor: string;
  fontFamily: string;
  logo: string;
};

export enum WidgetType {
  WITHDRAWAL = 'WITHDRAWAL',
  POST_DEPOSIT = 'POST_DEPOSIT',
}

export type TransactionTypeAllowed =
  | 'ALL'
  | 'VASP_2_VASP_ONLY'
  | 'SELF_TRANSACTION_ONLY';

export type NonCustodialDeclarationType =
  | 'SIGNATURE'
  | 'DECLARATION'
  | 'SIGNATURE_AND_DECLARATION';

export type OwnershipProofInput = {
  type?: string | null;
  proof?: string | null;
};

export type TransactionBlockchainInfo = {
  destination?: string | null;
  origin?: string | null;
};

export type CountryType = {
  id: string;
  name: string;
};

export type PersonType = 'natural' | 'legal';

export type OriginatorFields = {
  originatorAccountNumber?: string;
  originatorDid?: string;
  originatorVASPname?: string;
  originatorVASPdid?: string;
  originatorName?: string;
  originatorGeographicAddress?: string;
  originatorNationalIdentification?: NationalIdentification;
  originatorDateAndPlaceOfBirth?: DateAndPlaceOfBirth;
  originatorPersonType?: PersonType;
};

export type BeneficiaryFields = {
  beneficiaryAccountNumber?: string;
  beneficiaryDid?: string;
  beneficiaryVASPname?: string;
  beneficiaryVASPdid?: string;
  beneficiaryName?: string;
  beneficiaryGeographicAddress?: string;
  beneficiaryNationalIdentification?: NationalIdentification;
  beneficiaryDateAndPlaceOfBirth?: DateAndPlaceOfBirth;
  beneficiaryPersonType?: PersonType;
};

export type Transaction = OriginatorFields &
  BeneficiaryFields & {
    transactionAsset: string;
    transactionAmount: string;
    transactionBlockchainInfo?: TransactionBlockchainInfo;
    isNonCustodial?: boolean;
    originatorEqualsBeneficiary?: boolean;
    beneficiaryProof?: OwnershipProofInput;
    originatorProof?: OwnershipProofInput;
    isValid?: boolean;
    errors?: string[];
  };

export type FieldProps = {
  forceDisplay?: boolean; // instead of beneficiaryDetails - defaults to false
  optional?: boolean; // bypass the jurisdiction rules validation - defaults to false
};

export type FieldName =
  | 'counterparty'
  | 'geographicAddress'
  | 'name'
  | 'nationalIdentification'
  | 'dateAndPlaceOfBirth';

export type FieldsProps = {
  [name in FieldName]?: FieldProps;
};

==> javascript-sdk-1.21.0.tgz: package/src/types.ts <==
import { DateAndPlaceOfBirth, NationalIdentification } from 'ivms/types';

export type Theme = {
  primaryColor: string;
  secondaryColor: string;
  fontFamily: string;
  logo: string;
};

export enum WidgetType {
  WITHDRAWAL = 'WITHDRAWAL',
  POST_DEPOSIT = 'POST_DEPOSIT',
}

export type TransactionTypeAllowed =
  | 'ALL'
  | 'VASP_2_VASP_ONLY'
  | 'SELF_TRANSACTION_ONLY';

export type NonCustodialDeclarationType =
  | 'SIGNATURE'
  | 'DECLARATION'
  | 'SIGNATURE_AND_DECLARATION';

export type OwnershipProofInput = {
  type?: string | null;
  proof?: string | null;
};

export type TransactionBlockchainInfo = {
  destination?: string | null;
  origin?: string | null;
};

export type CountryType = {
  id: string;
  name: string;
};

export type PersonType = 'natural' | 'legal';

export type OriginatorFields = {
  originatorAccountNumber?: string;
  originatorDid?: string;
  originatorVASPname?: string;
  originatorVASPdid?: string;
  originatorName?: string;
  originatorGeographicAddress?: string;
  originatorNationalIdentification?: NationalIdentification;
  originatorDateAndPlaceOfBirth?: DateAndPlaceOfBirth;
  originatorPersonType?: PersonType;
};

export type BeneficiaryFields = {
  beneficiaryAccountNumber?: string;
  beneficiaryDid?: string;
  beneficiaryVASPname?: string;
  beneficiaryVASPdid?: string;
  beneficiaryName?: string;
  beneficiaryGeographicAddress?: string;
  beneficiaryNationalIdentification?: NationalIdentification;
  beneficiaryDateAndPlaceOfBirth?: DateAndPlaceOfBirth;
  beneficiaryPersonType?: PersonType;
};

export type CAIP19 = {
  caip19: string;
};

export type CoingeckoIdAndNetwork = { coingeckoId: string; network: string };

export type TransactionAsset = string | CAIP19 | CoingeckoIdAndNetwork;
export type Transaction = OriginatorFields &
  BeneficiaryFields & {
    transactionAsset: TransactionAsset;
    transactionAmount: string;
    transactionBlockchainInfo?: TransactionBlockchainInfo;
    isNonCustodial?: boolean;
    originatorEqualsBeneficiary?: boolean;
    beneficiaryProof?: OwnershipProofInput;
    originatorProof?: OwnershipProofInput;
    isValid?: boolean;
    errors?: string[];
  };

export type FieldProps = {
  forceDisplay?: boolean; // instead of beneficiaryDetails - defaults to false
  optional?: boolean; // bypass the jurisdiction rules validation - defaults to false
};

export type FieldName =
  | 'counterparty'
  | 'geographicAddress'
  | 'name'
  | 'nationalIdentification'
  | 'dateAndPlaceOfBirth';

export type FieldsProps = {
  [name in FieldName]?: FieldProps;
};
